
/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.file.zipentryprocessing;

import java.io.IOException;
import java.io.InputStream;
import java.util.zip.ZipEntry;

import de.unkrig.commons.lang.protocol.Predicate;

public
class SelectiveZipEntryProcessor implements ZipEntryProcessor {

    private final Predicate<String> pathPredicate;
    private final ZipEntryProcessor delegate1, delegate2;

    public
    SelectiveZipEntryProcessor(Predicate<String> pathPredicate, ZipEntryProcessor delegate1, ZipEntryProcessor delegate2) {
        this.pathPredicate = pathPredicate;
        this.delegate1 = delegate1;
        this.delegate2 = delegate2;
    }

    @Override public void
    process(ZipEntry ze, String path, InputStream inputStream) throws IOException {
        if (this.pathPredicate.evaluate(path)) {
            this.delegate1.process(ze, path, inputStream);
        } else {
            this.delegate2.process(ze, path, inputStream);
        }
    }
}
