
/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.lang;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.unkrig.commons.lang.protocol.RunnableWhichThrows;

public
class OrderedRunnables<EX extends Exception> {

    private final List<RunnableWhichThrows<EX>>              result = new ArrayList<RunnableWhichThrows<EX>>();
    private final Map<Object, List<RunnableWhichThrows<EX>>> map = new HashMap<Object, List<RunnableWhichThrows<EX>>>();

    public void
    add(RunnableWhichThrows<EX> runnable) {
        this.result.add(runnable);
    }

    public void
    add(RunnableWhichThrows<EX> r, Object target) {
        {
            List<RunnableWhichThrows<EX>> list = this.map.get(target);
            if (list != null) {
                list.add(r);
                return;
            }
        }

        final List<RunnableWhichThrows<EX>> list = new ArrayList<RunnableWhichThrows<EX>>();
        list.add(r);
        this.map.put(target, list);
        this.result.add(new RunnableWhichThrows<EX>() {

            @Override public void
            run() throws EX {
                for (RunnableWhichThrows<EX> runnable : list) {
                    runnable.run();
                }
            }
        });
    }

    public List<RunnableWhichThrows<EX>>
    getRunnables() {
        return this.result;
    }
}
