
/*
 * de.unkrig.commons - A general-purpose Java class library
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.commons.util;

import java.lang.management.ManagementFactory;
import java.lang.management.ThreadMXBean;
import java.text.MessageFormat;

public
class ThreadBenchmark {
    private static final ThreadMXBean threadMXBean = ManagementFactory.getThreadMXBean();
    private static final MessageFormat FORMAT1 = new MessageFormat("Real={0}ms Cpu={1}ns User={2}ns");
    private static final MessageFormat FORMAT2 = new MessageFormat("{0}ms");

    private long realTime;
    private long cpuTime;
    private long userTime;

    public
    ThreadBenchmark() {
        this.realTime = System.currentTimeMillis();
        if (threadMXBean.isCurrentThreadCpuTimeSupported()) {
            this.cpuTime = threadMXBean.getCurrentThreadCpuTime();
            this.userTime = threadMXBean.getCurrentThreadUserTime();
        }
    }

    public double
    getRealTime() {
        return 0.001D * (System.currentTimeMillis() - this.realTime);
    }

    public double
    getCpuTime() {
        return 0.000000001D * (threadMXBean.getCurrentThreadCpuTime() - this.cpuTime);
    }

    public double
    getUserTime() {
        return 0.000000001D * (threadMXBean.getCurrentThreadUserTime() - this.userTime);
    }

    public String
    getMessage() {
        if (threadMXBean.isCurrentThreadCpuTimeSupported()) {
            return FORMAT1.format(new Object[] {
                System.currentTimeMillis() - this.realTime,
                threadMXBean.getCurrentThreadCpuTime() - this.cpuTime,
                threadMXBean.getCurrentThreadUserTime() - this.userTime
            });
        }

        return FORMAT2.format(Long.valueOf(System.currentTimeMillis() - this.realTime));
    }
}
