
/*
 * de.unkrig.loggifier - Injects logging code into JAVA[TM] class files
 *
 * Copyright (c) 2011, Arno Unkrig
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *       following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *       following disclaimer in the documentation and/or other materials provided with the distribution.
 *    3. The name of the author may not be used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package de.unkrig.loggifier.runtime.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Controls loggification of the annotated class/interface/constructor/method. Its values are rules in the
 * following format:
 * <br>
 * &nbsp;&nbsp;<i>actions</i> '=' <i>level</i> [ ':' <i>expression</i> ]
 * <br>
 * <i>actions</i> is a comma-separated list of {@link de.unkrig.loggifier.Loggifier.Action}s and 'ALL'.<br>
 * <i>level</i> is one of {@link java.util.logging.Level}<br>
 * <i>expression</i> is something like {@code class =* 'A*' && (source =* '*.java' || line == 100)}
 */
@Target({
    ElementType.TYPE,             // Classes, interface, annotation, enum
    ElementType.CONSTRUCTOR,
    ElementType.METHOD,
}) @Retention(RetentionPolicy.CLASS) public @interface
Loggify {
    String[] value();
}
